#if !defined(AFX_HEADERVIEW_H__3806C815_6C67_4F02_9B02_A83E5DEBF12A__INCLUDED_)
#define AFX_HEADERVIEW_H__3806C815_6C67_4F02_9B02_A83E5DEBF12A__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// HeaderView.h : wb_[ t@C
//

#include "BitmapRichEditView.h"

/////////////////////////////////////////////////////////////////////////////
// CHeaderView r[

class CHeaderView : public CBitmapRichEditView
{
protected:
	CHeaderView();           // IɎgpveNg RXgN^
	DECLARE_DYNCREATE(CHeaderView)

// Agr[g
public:

// Iy[V
public:
	void SetHeaderText(CString buf);
	void SetFontEx(LOGFONT &lf);
	CFont m_font;
	void Clear();

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B

	//{{AFX_VIRTUAL(CHeaderView)
	public:
	virtual void OnInitialUpdate();
	protected:
	virtual void OnDraw(CDC* pDC);      // ̃r[`悷邽߂ɃI[o[Ch܂B
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	//}}AFX_VIRTUAL

// Cve[V
protected:
	virtual ~CHeaderView();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif

	// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CHeaderView)
	afx_msg BOOL OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
private:
	long m_onlink;
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_HEADERVIEW_H__3806C815_6C67_4F02_9B02_A83E5DEBF12A__INCLUDED_)
